summaryrefslogtreecommitdiffstats
path: root/khtml/html/html_miscimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/html/html_miscimpl.cpp')
-rw-r--r--khtml/html/html_miscimpl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/html/html_miscimpl.cpp b/khtml/html/html_miscimpl.cpp
index 84460195c..58804bff5 100644
--- a/khtml/html/html_miscimpl.cpp
+++ b/khtml/html/html_miscimpl.cpp
@@ -225,7 +225,7 @@ NodeImpl *HTMLCollectionImpl::item ( unsigned long index ) const
HTMLTableSectionElementImpl* section;
NodeImpl* found = 0;
- if (table->tqfindRowSection(index, section, sectionIndex)) {
+ if (table->findRowSection(index, section, sectionIndex)) {
HTMLCollectionImpl rows(section, TSECTION_ROWS);
found = rows.item(sectionIndex);
}
@@ -290,7 +290,7 @@ TQValueList<NodeImpl*> HTMLCollectionImpl::namedItems( const DOMString &name ) c
//remember stuff about elements we were asked for.
m_cache->updateNodeListInfo(m_refNode->getDocument());
CollectionCache* cache = static_cast<CollectionCache*>(m_cache);
- if (TQValueList<NodeImpl*>* info = cache->nameCache.tqfind(key)) {
+ if (TQValueList<NodeImpl*>* info = cache->nameCache.find(key)) {
return *info;
}
else {
@@ -366,7 +366,7 @@ NodeImpl *HTMLFormCollectionImpl::nextNamedItem( const DOMString &name ) const
{
TQPtrList<HTMLGenericFormElementImpl>& l = static_cast<HTMLFormElementImpl*>( m_refNode )->formElements;
//Go through the list, trying to tqfind the appropriate named form element.
for ( ; currentNamePos < l.count(); ++currentNamePos )
{
HTMLGenericFormElementImpl* el = l.at(currentNamePos);
@@ -366,7 +366,7 @@ NodeImpl *HTMLFormCollectionImpl::nextNamedItem( const DOMString &name ) const
{
TQPtrList<HTMLGenericFormElementImpl>& l = static_cast<HTMLFormElementImpl*>( m_refNode )->formElements;
- //Go through the list, trying to tqfind the appropriate named form element.
+ //Go through the list, trying to find the appropriate named form element.
for ( ; currentNamePos < l.count(); ++currentNamePos )
{